@@ -145,7 +145,10 @@ class Faginator(View):
 
         try:
             def check(i, view):
-                return (i.message.id == view.message.id) * ((i.user == view.ctx.author) if view.only_author else True)
+                if isinstance(view.ctx, discord.Interaction):
+                    return (i.message.id == view.message.id) * ((i.user == view.ctx.user) if view.only_author else True)
+                else:
+                    return (i.message.id == view.message.id) * ((i.user == view.ctx.author) if view.only_author else True)
 
             async def back_callback(interaction):
                 if check(interaction, view):
@@ -259,12 +262,17 @@ class Faginator(View):
             if type == 'slash':
                 await view.ctx.respond(view=view, embed=res[0], content=res[1], ephemeral=ephemeral)
             elif type == 'interaction':
+                view.ctx = interact
                 await interact.response.send_message(view=view, embed=res[0], content=res[1], ephemeral=ephemeral)
             elif type == 'text':
                 await view.ctx.send(view=view, embed=res[0], content=res[1])
 
             view.back_button.disabled = True
-            message = await view.ctx.fetch_message(view.message.id)
+            if isinstance(view.ctx, discord.Interaction):
+                message = view.message
+            else:
+                message = await view.ctx.fetch_message(view.message.id)
+
             view.message = message
             await view.message.edit(view=view, embed=res[0], content=res[1])
 
